==> static-compat-qt6-quick3d-6.9.1-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Quick3D/Qt6Quick3DTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::Quick3D" for configuration "Release"
set_property(TARGET Qt6::Quick3D APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3D PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LINK_INTERFACE_MULTIPLICITY_RELEASE "3"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6Quick3D.a"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3D )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3D "${_IMPORT_PREFIX}/lib/libQt6Quick3D.a" )

# Import target "Qt6::Quick3D_resources_1" for configuration "Release"
set_property(TARGET Qt6::Quick3D_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3D_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/objects-Release/Quick3D_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3D_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3D_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/objects-Release/Quick3D_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> static-compat-qt6-quick3d-6.10.0-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Quick3D/Qt6Quick3DTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::Quick3D" for configuration "Release"
set_property(TARGET Qt6::Quick3D APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3D PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LINK_INTERFACE_MULTIPLICITY_RELEASE "3"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6Quick3D.a"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3D )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3D "${_IMPORT_PREFIX}/lib/libQt6Quick3D.a" )

# Import target "Qt6::Quick3D_resources_1" for configuration "Release"
set_property(TARGET Qt6::Quick3D_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3D_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/objects-Release/Quick3D_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3D_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3D_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/objects-Release/Quick3D_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_init.cpp.o" )

# Import target "Qt6::Quick3D_resources_2" for configuration "Release"
set_property(TARGET Qt6::Quick3D_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3D_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/objects-Release/Quick3D_resources_2/.qt/rcc/qrc_Quick3D_raw_qml_0_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3D_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3D_resources_2 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/objects-Release/Quick3D_resources_2/.qt/rcc/qrc_Quick3D_raw_qml_0_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
